@@ -4,7 +4,7 @@ use warnings;
 
 package OCS::Client;
 {
-  $OCS::Client::VERSION = '0.007';
+  $OCS::Client::VERSION = '0.008';
 }
 # ABSTRACT: A simple interface to OCS's SOAP API
 
@@ -65,7 +65,7 @@ sub get_computers_V1 {
     shift @computers;
     pop   @computers;
 
-    return map {XMLin($_, ForceArray => [qw/DRIVES NETWORKS PRINTERS SOFTWARES VIDEOS/])} @computers;
+    return map {XMLin($_, ForceArray => [qw/DRIVES HARDWARE NETWORKS PRINTERS SOFTWARES STORAGES VIDEOS/])} @computers;
 }
 
 
@@ -204,7 +204,7 @@ OCS::Client - A simple interface to OCS's SOAP API
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -266,7 +266,7 @@ as a data structure that is converted from its XML original
 representation into a Perl data structure by the XML::Simple::XMLin
 function.
 
-=head3 B<computer_iterator> REQUEST-LIST
+=head3 B<computer_iterator> REQUEST-MAP
 
 This method returns a closure that you can use to fetch the computers
 one by one until there is no more. It's usefull because the server
@@ -294,60 +294,35 @@ field names of my company's OCS instance. You should redefine it in
 your script if you intend to use this method. (May the source be with
 you, Luke!)
 
-=head2 Constants
+=head2 CONSTANTS
 
 This module defines some constants to make the calling of methods
 B<get_computers_V1> and B<computer_iterator> easier and more readable.
 
 These are for their CHECKSUM parameter.
 
-=over 4
-
-=item HARDWARE            => 0x00001
-
-=item BIOS                => 0x00002
-
-=item MEMORY_SLOTS        => 0x00004
-
-=item SYSTEM_SLOTS        => 0x00008
-
-=item REGISTRY            => 0x00010
-
-=item SYSTEM_CONTROLLERS  => 0x00020
-
-=item MONITORS            => 0x00040
-
-=item SYSTEM_PORTS        => 0x00080
-
-=item STORAGE_PERIPHERALS => 0x00100
-
-=item LOGICAL_DRIVES      => 0x00200
-
-=item INPUT_DEVICES       => 0x00400
-
-=item MODEMS              => 0x00800
-
-=item NETWORK_ADAPTERS    => 0x01000
-
-=item PRINTERS            => 0x02000
-
-=item SOUND_ADAPTERS      => 0x04000
-
-=item VIDEO_ADAPTERS      => 0x08000
-
-=item SOFTWARE            => 0x10000
-
-=back
+    'HARDWARE'            => 0x00001,
+    'BIOS'                => 0x00002,
+    'MEMORY_SLOTS'        => 0x00004,
+    'SYSTEM_SLOTS'        => 0x00008,
+    'REGISTRY'            => 0x00010,
+    'SYSTEM_CONTROLLERS'  => 0x00020,
+    'MONITORS'            => 0x00040,
+    'SYSTEM_PORTS'        => 0x00080,
+    'STORAGE_PERIPHERALS' => 0x00100,
+    'LOGICAL_DRIVES'      => 0x00200,
+    'INPUT_DEVICES'       => 0x00400,
+    'MODEMS'              => 0x00800,
+    'NETWORK_ADAPTERS'    => 0x01000,
+    'PRINTERS'            => 0x02000,
+    'SOUND_ADAPTERS'      => 0x04000,
+    'VIDEO_ADAPTERS'      => 0x08000,
+    'SOFTWARE'            => 0x10000,
 
 And these are for their WANTED parameter.
 
-=over 4
-
-=item ACOUNTINFO          => 0x00001
-
-=item DICO_SOFT           => 0x00002
-
-=back
+    'ACOUNTINFO'          => 0x00001,
+    'DICO_SOFT'           => 0x00002,
 
 =head1 AUTHOR
 
